%----------------------------------------------------------------------------------
%
% Description :
% This function M-file computes beta on the accordance with the two-path model of TSV model.
%
% Programmed by R. Funada, H. Sawada, H. Harada, Y. Shoji, and S. Kato (18-Dec-2006)
%----------------------------------------------------------------------------------
% Comment
%	change calc_ant_gain_pre_fin_rev2 to calc_ant_gain_pre_fin_rev3

function [beta] = tg3c_tsv_beta_calc_pre_fin_rev3(fc, muD, tx_hpang, rx_hpang, ant_type)

%  Arguments:
% Parameters used for beta calculation
%   fs			: Center carrier frequency
%   muD			: Average distance between TX and RX
%	tx_hpang	: TX half-power angle in deg (horizontal and vartical gain are same)
%	rx_hpang	: RX half-power angle in deg (horizontal and vartical gain are same)
%	ant_type	: Types of antenna pattern

%%%%%%%%%%%%%%%  Beta calculation (Monte carlo based)  %%%%%%%%%%%%%%%%%%%%

%	gamma0		: Reflection coefficient
gamma0	= 1;													% Assuming angle of incidence is large 

% this paramerres will be discussed
D0		= [-0.3 0.3]+muD;										% Range of D  (m)
Ht		= [0.0 0.30];												% Range of Ht (m)
Hr		= [0.0 0.30];												% Range of Hr (m)

% Determine TX and RX heights by the Monte-carlo method
h1	= (Ht(2)-Ht(1))*rand+Ht(1);
h2	= (Hr(2)-Hr(1))*rand+Hr(1);

% Determine distance between TX and RX by the Monte-carlo method
D	= (D0(2)-D0(1))*rand+D0(1);

% Wave length
ramda		= 3e8/fc;

%********** Calculate the reflection point of the relrection path **********
tx_p	= i.*h1;
rx_p	= D+i.*h2;
rfl_p	= D*h1/(h1+h2);

%************ Determene direction of direct and reflection paths ***********
tp		= angle([rx_p-tx_p (tx_p-rx_p) rfl_p-tx_p (rfl_p-rx_p)]);
tp		= tp./pi*180;

dr_theta	= tp(1);
dr_fai		= dr_theta;
rfl_theta	= tp(3);
rfl_fai		= -rfl_theta;

%******************** Determine Antenna horizontal gain ********************
% TX-------------------
% Direct path
gt1	= calc_ant_gain_pre_fin_rev3(ant_type, tx_hpang, dr_theta);
% Reflection path
gt2	= calc_ant_gain_pre_fin_rev3(ant_type, tx_hpang, rfl_theta);

% RX-------------------
% Direct path
gr1	= calc_ant_gain_pre_fin_rev3(ant_type, rx_hpang, dr_fai);
% Reflection path
gr2	= calc_ant_gain_pre_fin_rev3(ant_type, rx_hpang, rfl_fai);

% calculation of sqrt is included in calc_ant_gain_pre_fin_rev1.m
beta	= (muD/D).*abs(gt1.*gr1+gt2.*gr2...
	.*gamma0.*exp(j.*(2*pi./ramda).*(2.*h1.*h2./D)));